from typing import Any, Tuple

from .properties import Configurations as Configurations
from .scripts import H2 as H2

class J2:
    convert: Any = ...
    def __init__(self, mode: str = ..., method: str = ...) -> None: ...
    def isRegion(self, c: str) -> Any: ...
    def isCletter(self, literal: str, c: str) -> bool: ...
    def convert_h(self, itext: Any) -> Tuple[str, int]: ...
    def convert_nonh(self, text: Any): ...
    def convert_noop(self, text: Any): ...

class Itaiji:
    __dict__: Any = ...
    def __new__(cls, *p: Any, **k: Any): ...
    def __init__(self) -> None: ...
    def haskey(self, c: Any): ...
    def convert(self, text: str) -> str: ...

class Kanwa:
    __dict__: Any = ...
    def __new__(cls, *p: Any, **k: Any): ...
    def __init__(self) -> None: ...
    def load(self, char: str) -> Any: ...
